package FBP::ListCtrl;

use Mouse;

our $VERSION = '0.05';

extends 'FBP::Window';
with    'FBP::Control';

1;
